@@ -60,6 +60,7 @@ struct alc {
 int mic_max_display;				// display value of maximum microphone signal level 0 to 2**15 - 1
 int quiskSpotLevel = -1;			// level is -1 for Spot button Off; else the Spot level 0 to 1000.
 int quiskImdLevel = 500;			// level for rxMode IMD, 0 to 1000
+int hermes_mox_bit;				// mox bit to send to Hermes
 
 static SOCKET mic_socket = INVALID_SOCKET;	// send microphone samples to a socket
 static double mic_agc_level = 0.10;		// Mic levels below this are noise and are ignored
@@ -889,7 +890,7 @@ static void quisk_hermes_tx_add(complex double * cSamples, int tx_count, int key
 void quisk_hermes_tx_send(int tx_socket, int * tx_records)
 {	// Send one UDP block of mic samples using the Metis-Hermes protocol.  Timing is from blocks received, rate is 48k.
 	// If the key is up we send samples anyway, but the samples are zero.
-	int i, j, offset, sent, ratio, mox_bit;
+	int i, j, offset, sent, ratio;
 	short s;
 	unsigned char sendbuf[1032];
 	unsigned char * pt_buf;
@@ -909,7 +910,13 @@ void quisk_hermes_tx_send(int tx_socket, int * tx_records)
 		last_play_state = quisk_play_state;
 		serial_key_samples(NULL, 0);
 	}
-	if (quisk_play_state == SOFTWARE_CWKEY) {
+	//printf("hermes_tx_send start 2: hermes_num_samples %d\n", hermes_num_samples);
+	ratio = quisk_sound_state.sample_rate / 48000;		// send rate is 48 ksps
+	//printf ("quisk_hermes_tx_send ratio %d count %d\n", ratio, *tx_records);
+	if (*tx_records / ratio < 63 * 2)		// tx_records is the number of samples received for each receiver
+		return;
+	// Send 63*2 Tx samples with control bytes
+	if (quisk_play_state == SOFTWARE_CWKEY) {	// Send CW samples
 		serial_key_samples(cw_samples, 63 * 2);
 		j = 0;
 		for (i = 0; i < 63 * 2; i++) {
@@ -919,21 +926,6 @@ void quisk_hermes_tx_send(int tx_socket, int * tx_records)
 		hermes_read_index = 0;
 		hermes_num_samples = 63 * 2;
 	}
-	if (quisk_is_key_down()) {
-		if (quisk_play_state == HARDWARE_CWKEY)
-			mox_bit = 0;
-		else
-			mox_bit = 1;
-	}
-	else {
-		mox_bit = 0;
-	}
-	//printf("hermes_tx_send start 2: hermes_num_samples %d\n", hermes_num_samples);
-	ratio = quisk_sound_state.sample_rate / 48000;		// send rate is 48 ksps
-	//printf ("quisk_hermes_tx_send ratio %d count %d\n", ratio, *tx_records);
-	if (*tx_records / ratio < 63 * 2)		// tx_records is the number of samples received for each receiver
-		return;
-	// Send 63*2 Tx samples with control bytes
 	//printf ("Buffer usage %.1f %%\n", 100.0 * hermes_num_samples / HERMES_TX_BUF_SAMPLES);
 	//printf ("Tx  quisk_hermes_tx_send ratio %d, count %d, samples %d\n", ratio, *tx_records, hermes_num_samples);
 	*tx_records -= 63 * 2 * ratio;
@@ -956,14 +948,14 @@ void quisk_hermes_tx_send(int tx_socket, int * tx_records)
 	sendbuf[9] = 0x7F;
 	sendbuf[10] = 0x7F;
 	offset = C0_index * 4;		// offset into quisk_pc_to_hermes is C0[7:1] * 4
-	sendbuf[11] = C0_index << 1 | mox_bit;			// C0
+	sendbuf[11] = C0_index << 1 | hermes_mox_bit;			// C0
 	sendbuf[12] = quisk_pc_to_hermes[offset++];		// C1
 	sendbuf[13] = quisk_pc_to_hermes[offset++];		// C2
 	sendbuf[14] = quisk_pc_to_hermes[offset++];		// C3
 	sendbuf[15] = quisk_pc_to_hermes[offset++];		// C4
 	if (C0_index == 0) {	// Do not change receiver count without stopping Hermes and restarting
 		sendbuf[15] = quisk_multirx_count << 3 | 0x04;	// Send the old count, not the changed count
-		if (mox_bit)		// send filter selection on J16
+		if (hermes_mox_bit)		// send filter selection on J16
 			sendbuf[13] = hermes_filter_tx << 1;
 		else
 			sendbuf[13] = hermes_filter_rx << 1;
@@ -996,7 +988,7 @@ void quisk_hermes_tx_send(int tx_socket, int * tx_records)
 
 		// Only send periodic hermeslite writes in second part of frame
 		hlwp = 5*(quisk_hermeslite_writepointer-1);
-		sendbuf[523] = quisk_hermeslite_writequeue[hlwp++] << 1 | mox_bit;
+		sendbuf[523] = quisk_hermeslite_writequeue[hlwp++] << 1 | hermes_mox_bit;
 		sendbuf[524] = quisk_hermeslite_writequeue[hlwp++];
 		sendbuf[525] = quisk_hermeslite_writequeue[hlwp++];
 		sendbuf[526] = quisk_hermeslite_writequeue[hlwp++];
@@ -1009,14 +1001,14 @@ void quisk_hermes_tx_send(int tx_socket, int * tx_records)
 		}
 	} else {
 		offset = C0_index * 4;		// offset into quisk_pc_to_hermes is C0[7:1] * 4
-		sendbuf[523] = C0_index << 1 | mox_bit;		// C0
+		sendbuf[523] = C0_index << 1 | hermes_mox_bit;		// C0
 		sendbuf[524] = quisk_pc_to_hermes[offset++];		// C1
 		sendbuf[525] = quisk_pc_to_hermes[offset++];		// C2
 		sendbuf[526] = quisk_pc_to_hermes[offset++];		// C3
 		sendbuf[527] = quisk_pc_to_hermes[offset++];		// C4
 		if (C0_index == 0) {
 			sendbuf[527] = quisk_multirx_count << 3 | 0x04;		// Send the old count, not the changed count
-			if (mox_bit)		// send filter selection on J16
+			if (hermes_mox_bit)		// send filter selection on J16
 				sendbuf[525] = hermes_filter_tx << 1;
 			else
 				sendbuf[525] = hermes_filter_rx << 1;
@@ -1258,7 +1250,7 @@ int quisk_process_microphone(int mic_sample_rate, complex double * cSamples, int
 			cSamples[i] = 0;
 	}
 	if (key_down != key_was_down) {	
-		key_down_counter = 4800;	// Key was pressed. Zero the first few samples to clear the buffers.
+		key_down_counter = quisk_start_ssb_delay * 48;	// Key was pressed. Zero the first few samples to clear the buffers.
 		init_alc(&tx_alc, 0);		// init ALC for Tx and RECORD_MIC
 		key_was_down = key_down;
 	}
@@ -1579,11 +1571,10 @@ void quisk_set_tx_mode(void)	// called when the mode rxMode is changed
 }
 
 #define CW_RISE_MSEC	5
-#define CW_DELAY_MSEC	15
-#define CW_DELAY_SAMPLES	(CW_DELAY_MSEC * 48)
+#define CW_DELAY_SAMPLES	(START_CW_DELAY_MAX * 48)
 static void serial_key_samples(complex double * cSamples, int count)	// called from the sound thread
 {  // Internal CW from serial port key - fill cSamples with CW samples
-	int i, key_down;
+	int i, key_down, delay;
 	static double ampl = 0;
 	static char delay_line[CW_DELAY_SAMPLES];	// play CW a fixed delay after the key
 	static int delay_index;
@@ -1597,11 +1588,13 @@ static void serial_key_samples(complex double * cSamples, int count)	// called f
 		return;
 	}
 
+	delay = quisk_start_cw_delay * 48;
 	for (i = 0; i < count; i++) {
 		key_down = delay_line[delay_index];
 		delay_line[delay_index] =  QUISK_CWKEY_DOWN;
-		if (++delay_index >= CW_DELAY_SAMPLES)
+		if (++delay_index >= delay) {
 			delay_index = 0;
+		}
 		if (key_down) {		// key is down
 			if (ampl < themax) {
 				ampl += delta;
