@@ -281,6 +281,7 @@ extern unsigned int quisk_hermeslite_writepointer;		// write pointer into write
 extern unsigned int quisk_hermeslite_writeattempts;		// counter for write retries
 extern unsigned int quisk_hermes_code_version;			// Hermes code version from Hermes to PC
 extern unsigned int quisk_hermes_board_id;			// Hermes board ID from Hermes to PC
+extern int hermes_mox_bit;					// Hermes mox bit from the PC to Hermes
 extern int quisk_use_rx_udp;					// Method of access to UDP hardware
 extern complex double cRxFilterOut(complex double, int, int);
 extern int quisk_multirx_count;			// number of additional receivers zero or 1, 2, 3, ..
@@ -341,6 +342,11 @@ extern PyObject * quisk_set_sound_name(PyObject *, PyObject *);
 extern PyObject * quisk_alsa_control_midi(PyObject *, PyObject *, PyObject *);
 extern PyObject * quisk_wasapi_control_midi(PyObject *, PyObject *, PyObject *);
 
+// WDSP interface
+#define QUISK_WDSP_RX	1
+extern PyObject * quisk_wdsp_set_parameter(PyObject *, PyObject *, PyObject *);
+extern int wdspFexchange0(int, double *, int);
+
 // These function pointers are the Start/Stop/Read interface for
 // the SDR-IQ and any other C-language extension modules that return
 // radio data samples.
